Coverage for src\pqlattice\lattice\_embeddings.py: 68%

1 from ..typing import Matrix, SquareMatrix, Vector, validate_aliases

2

3

4@validate_aliases

5 def q_ary_lattice_basis(A: Matrix, modulus: int) -> SquareMatrix:

6 raise NotImplementedError()

7

8

9@validate_aliases

10 def dual_q_ary_lattice_basis(A: Matrix, modulus: int) -> SquareMatrix:

11 raise NotImplementedError()

12

13

14@validate_aliases

15 def bai_galbraith(A: Matrix, b: Vector, q: int) -> SquareMatrix:

16 raise NotImplementedError()

17

18

19@validate_aliases

20 def kannan(lattice_basis: SquareMatrix, target_vector: Vector, M: int) -> SquareMatrix:

21 raise NotImplementedError()

22

23

24@validate_aliases

25 def subset_sum(sequence: Vector, S: int) -> SquareMatrix:

26 raise NotImplementedError()

27

28

29@validate_aliases

30 def ntru() -> SquareMatrix:

31 raise NotImplementedError()